summaryrefslogtreecommitdiff
path: root/lundump.c
diff options
context:
space:
mode:
authorRoberto Ierusalimschy <roberto@inf.puc-rio.br>2014-03-27 12:58:05 -0300
committerRoberto Ierusalimschy <roberto@inf.puc-rio.br>2014-03-27 12:58:05 -0300
commit420cc62facc5b49d0aebfb9be7ddfe911d77ff97 (patch)
tree0ad2341511bd07e78434808b5e5a71f71bd5e323 /lundump.c
parent1a3ebc203a04a4b312d1692d41eeda7035ea0eef (diff)
downloadlua-github-420cc62facc5b49d0aebfb9be7ddfe911d77ff97.tar.gz
missplelling in comments/function names (endianess -> endianness)
Diffstat (limited to 'lundump.c')
-rw-r--r--lundump.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/lundump.c b/lundump.c
index e9d445e6..ddf55239 100644
--- a/lundump.c
+++ b/lundump.c
@@ -1,5 +1,5 @@
/*
-** $Id: lundump.c,v 2.33 2014/03/11 18:05:46 roberto Exp roberto $
+** $Id: lundump.c,v 2.34 2014/03/11 18:56:27 roberto Exp roberto $
** load precompiled Lua chunks
** See Copyright Notice in lua.h
*/
@@ -42,7 +42,7 @@ static l_noret error(LoadState *S, const char *why) {
/*
** All high-level loads go through LoadVector; you can change it to
** adapt to the endianess of the input
*/
#define LoadVector(S,b,n) LoadBlock(S,b,(n)*sizeof((b)[0]))
@@ -231,7 +231,7 @@ static void checkHeader (LoadState *S) {
checksize(S, lua_Integer);
checksize(S, lua_Number);
if (LoadInteger(S) != LUAC_INT)
- error(S, "endianess mismatch in");
+ error(S, "endianness mismatch in");
if (LoadNumber(S) != LUAC_NUM)
error(S, "float format mismatch in");
}
@@ -42,7 +42,7 @@ static l_noret error(LoadState *S, const char *why) {
/*
** All high-level loads go through LoadVector; you can change it to
-** adapt to the endianess of the input
+** adapt to the endianness of the input
*/
#define LoadVector(S,b,n) LoadBlock(S,b,(n)*sizeof((b)[0]))